# WhatsAppBot
This module helps is automating whats app chats

## Things you should have 
1. Chrome driver
2. Selenium Installed

## Download chrome driver from here
https://chromedriver.chromium.org/downloads

## Install selenium 
pip install selenium

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install whats_app_bot
```

## Usage

```python
import WhatsAppBot

bot = WhatsAppBot()
bot.send_text_to('username','message','numberoftimes')
# numberoftimes has default value as 1
```
